@@ -338,9 +338,11 @@ If ARG is nil, then toggle."
 
 (defface semantic-unmatched-syntax-face
   '((((class color) (background dark))
-     (:underline "red"))
+;     (:underline "red"))
+     (:background "red" :underline t))
     (((class color) (background light))
-     (:underline "red")))
+;     (:underline "red")))
+     (:background "red" :underline t)))
   "*Face used to show unmatched-syntax in.
 The face is used in  `semantic-show-unmatched-syntax-mode'."
   :group 'semantic)
